Mesa (main): ac: Check me_fw_feature for 32bit predication on gfx10.3

GitLab Mirror gitlab-mirror at kemper.freedesktop.org
Fri Jun 11 06:25:26 UTC 2021


Module: Mesa
Branch: main
Commit: a41ba20cbd0814d2f963929b27a787f043b5a27c
URL:    http://cgit.freedesktop.org/mesa/mesa/commit/?id=a41ba20cbd0814d2f963929b27a787f043b5a27c

Author: Georg Lehmann <dadschoorse at gmail.com>
Date:   Thu Jun 10 12:46:22 2021 +0200

ac: Check me_fw_feature for 32bit predication on gfx10.3

Signed-off-by: Georg Lehmann <dadschoorse at gmail.com>
Reviewed-by: Samuel Pitoiset <samuel.pitoiset at gmail.com>
Reviewed-by: Marek Olšák <marek.olsak at amd.com>
Part-of: <https://gitlab.freedesktop.org/mesa/mesa/-/merge_requests/11297>

---

 src/amd/common/ac_gpu_info.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/amd/common/ac_gpu_info.c b/src/amd/common/ac_gpu_info.c
index fc8ee3c5fc0..ab778a36e20 100644
--- a/src/amd/common/ac_gpu_info.c
+++ b/src/amd/common/ac_gpu_info.c
@@ -907,10 +907,10 @@ bool ac_query_gpu_info(int fd, void *dev_p, struct radeon_info *info,
                                         info->family == CHIP_SIENNA_CICHLID;
 
    /* Support for GFX10.3 was added with F32_ME_FEATURE_VERSION_31 but the
     * firmware version wasn't bumped.
     */
    info->has_32bit_predication = info->chip_class >= GFX10_3 &&
-                                 info->me_fw_version >= 32;
+                                 info->me_fw_feature >= 32;
 
    /* Get the number of good compute units. */
    info->num_good_compute_units = 0;
@@ -907,10 +907,10 @@ bool ac_query_gpu_info(int fd, void *dev_p, struct radeon_info *info,
 
    /* Support for GFX10.3 was added with F32_ME_FEATURE_VERSION_31 but the
-    * firmware version wasn't bumped.
+    * feature version wasn't bumped.
     */
    info->has_32bit_predication = info->chip_class >= GFX10_3 &&



More information about the mesa-commit mailing list